@@ -22,7 +22,7 @@ matchers = {
 "vpg":  new_matcher([[{"POS": 'VERB'}, {"POS": {"IN": ["PREP", "ADP",'PART']}, "OP": "+"},{"TAG": 'VBG'}]]),   # insisted on going
 "vAp":  new_matcher([[{'LEMMA': 'be'},{"TAG": {"IN": ["VBN"]}}, {"POS": {"IN": ["PREP", "ADP",'PART']}}]]),   # be based on   
 "vap":  new_matcher([[{'LEMMA': 'be'},{"POS": {"IN": ["ADJ"]}}, {"POS": {"IN": ["PREP", "ADP",'PART']}}]]),   # be angry with
-} #for name, ibeg,iend in matchers['ap'](doc) : print(doc[ibeg:iend].text)
+} #for name, ibeg,iend in matcher(doc) : print(spacy.nlp.vocab[name].text, doc[ibeg:iend].text)
 
 def new_depmatcher(pattern, name='pat'):
 	matcher = DependencyMatcher(spacy.nlp.vocab)
@@ -278,9 +278,9 @@ def attach(doc):
 			"pos":t.pos_, "tag":t.tag_, "dep":t.dep_ , "head":t.head.lemma_, "offset":round(t.i/len(doc),2)}) for t in doc]
 		[ ssv[f"trp-{t.i}"].update ({"type":"trp", "gov": t.head.lemma_, "rel":f"{t.dep_}_{t.head.pos_}_{t.pos_}", "dep":t.lemma_, "govpos":t.head.pos_, "deppos":t.pos_}) for t in doc if t.dep_ not in ('punct') and t.pos_ not in ('PUNCT','SPACE')] #'ROOT',
 		[ ssv[f"rootv-{t.i}"].update ({"type":"rootv", "lem": t.lemma_, "pos":t.pos_, "tag":t.tag_}) for t in doc if t.dep_ =='ROOT']
-		[ ssv[f"vvbg-{t.i}"].update ({"type":"vvbg", "lem": t.head.lemma_, "chunk":f"{t.head.lemma_} {t.text.lower()}", "tail":t.lemma})
+		[ ssv[f"vvbg-{t.i}"].update ({"type":"vvbg", "lem": t.head.lemma_, "chunk":f"{t.head.lemma_} {t.text.lower()}", "kp":f"{t.head.lemma_} DOING", "tail":t.lemma})
 			 for t in doc if t.dep_ =='xcomp' and t.head.pos_ == 'VERB' and t.tag_ == 'VBG' and t.lemma_.isalpha() and t.head.lemma_.isalpha()]   #I enjoy smiling. 
-		[ ssv[f"vtov-{t.i}"].update ({"type":"vtov", "lem": t.head.lemma_, "tail":t.text.lower(), "chunk":f"{t.head.lemma_} to {t.text.lower()}"})
+		[ ssv[f"vtov-{t.i}"].update ({"type":"vtov", "lem": t.head.lemma_, "tail":t.text.lower(), "chunk":f"{t.head.lemma_} to {t.text.lower()}", "kp":f"{t.head.lemma_} to DO"}) # begin to DO:go 
 			 for t in doc if t.dep_ =='xcomp' and t.head.pos_ == 'VERB' and t.tag_ == 'VB' and t.i > 1 and t.doc[t.i-1].tag_ == 'TO' and t.head.text.isalpha() and t.head.lemma_.isalpha()]   #I plan to go. 
 		[ ssv[f"mdv-{t.i}"].update ({"type":"mdv","lem":t.head.lemma_, "chunk":f"{t.head.lemma_} {t.lemma_}"}) for t in doc  if t.tag_ == 'MD' and t.dep_ =='aux' and t.head.pos_ == 'VERB' and t.head.lemma_.isalpha()]
 		[ ssv[f"np-{sp.start}"].update ({"type":"np","lem":sp.root.lemma_.lower(), "chunk":sp.text.lower()})
@@ -427,13 +427,12 @@ def es_terms(doc):  # added 2021.10.13
 	[ ( s:=doc[x[1]].lemma_, v:=doc[x[0]].lemma_, o:=doc[x[2]].lemma_, 
 	    incr(si, f"svo:{v}:{s} {o}")) for name, x in depmatchers["svo"](doc) ]
 	[ ( s:=doc[x[1]].lemma_, v:=doc[x[0]].lemma_, a:=doc[x[2]].lemma_, incr(si, f"{a}:sva:{s} {v} {a}")) for name, x in depmatchers["sva"](doc) ]
-	[ ( s:=doc[x[1]].lemma_, a:=doc[x[2]].lemma_, incr(si, f"{a}:sbea:{s}")) for name, x in depmatchers["sbea"](doc) ] # the girl is happy
+	#[ ( s:=doc[x[1]].lemma_, a:=doc[x[2]].lemma_, incr(si, f"{a}:sbea:{s}")) for name, x in depmatchers["sbea"](doc) ] # the girl is happy
 	[ ( s:=doc[z[1]].lemma_, v:=doc[z[0]].lemma_, x:=doc[z[2]].lemma_, 
 		incr(si, f"svx:{v}:{s} {x}")) for name, z in depmatchers["svx"](doc) ]
 	[ ( s:=doc[x[1]].lemma_, v:=doc[x[0]].lemma_, c:=doc[x[2]].lemma_, 
 		incr(si, f"svc:{v}:{s} {c}")) for name, x in depmatchers["svc"](doc) ]
-	[ ( s:=doc[x[1]].lemma_, v:=doc[x[0]].lemma_, c:=doc[x[2]].lemma_, 
-		incr(si, f"sbea:{s} {c}")) for name, x in depmatchers["sbea"](doc) ]
+	#[ ( s:=doc[x[1]].lemma_, v:=doc[x[0]].lemma_, c:=doc[x[2]].lemma_, 	incr(si, f"sbea:{s} {c}")) for name, x in depmatchers["sbea"](doc) ]
 	[ ( v:=doc[x[0]].lemma_, p:=doc[x[1]].lemma_, n:=doc[x[2]].lemma_, 
 		incr(si, f"vpn:{v} {p} {n}")) for name, x in depmatchers["vpn"](doc) ]
 	[ ( v:=doc[x[0]].lemma_, a:=doc[x[1]].lemma_, p:=doc[x[2]].lemma_, 
